=== modified file '.bzrignore'
--- .bzrignore	2015-11-02 23:06:58 +0000
+++ .bzrignore	2017-02-28 12:00:55 +0000
@@ -3,6 +3,7 @@
 dist/
 build/
 MANIFEST
+charmhelpers.egg-info/
 charmhelpers/version.py
 .coverage
 .env/

=== modified file 'charmhelpers/contrib/snap/__init__.py'
--- charmhelpers/contrib/snap/__init__.py	2017-02-24 14:11:56 +0000
+++ charmhelpers/contrib/snap/__init__.py	2017-02-28 12:00:55 +0000
@@ -36,74 +36,72 @@
     proc.wait()
 
     if proc.returncode > 0:
-        log('`snap %s` exited with a non-zero status' % ' '.join(commands),
-            level='FATAL')
+        log(
+            '`snap %s` exited with a non-zero status' % ' '.join(commands),
+            level='FATAL'
+        )
 
     return proc.returncode
 
 
-def snap_install(package, edge=False, beta=False, candidate=False, stable=False, devmode=False, jailmode=False,
-                 classic=False, dangerous=False, channel=None, revision=None):
+def snap_install(packages, *flags):
     """
     Install a snap package.
 
-    :param package: String or List String package name
-    :param edge: Boolean install from the edge channel
-    :param beta: Boolean install from the beta channel
-    :param candidate: Boolean install from the candidate channel
-    :param stable: Boolean install from the stable channel
-    :param devmode: Boolean put snap in development mode and disable security confinement
-    :param jailmode: Boolean put snap in enforced confinement mode
-    :param classic: Boolean put snap in classic mode and disable security confinement
-    :param dangerous: Boolean install the given snap file even if there are no pre-acknowledged signatures for
-           it, meaning it was not verified and could be dangerous (--devmode implies this)
-    :param channel: String use this channel instead of stable
-    :param revision: String install the given revision of a snap, to which you must have developer access
-    :return: None
+    :param packages: String or List String package name
+    :param flags: List String flags to pass to install command
+    :return: Integer return code from snap
     """
-    if type(package) is not list:
-        package = [package]
-
-    flags = []
-
-    if edge:
-        flags.append('--edge')
-    if beta:
-        flags.append('--beta')
-    if candidate:
-        flags.append('--candidate')
-    if stable:
-        flags.append('--stable')
-    if devmode:
-        flags.append('--devmode')
-    if jailmode:
-        flags.append('--jailmode')
-    if classic:
-        flags.append('--classic')
-    if dangerous:
-        flags.append('--dangerous')
-    if channel:
-        flags.append('--channel=%s' % channel)
-    if revision:
-        flags.append('--revision=%s' % revision)
-
-    message = 'Installing snap "%s"' % package
+    if type(packages) is not list:
+        packages = [packages]
+
+    flags = list(flags)
+
+    message = 'Installing snap(s) "%s"' % ', '.join(packages)
     if flags:
-        message += ' with options "%s"' % ' '.join(flags)
+        message += ' with option(s) "%s"' % ', '.join(flags)
 
     log(message)
-    _snap_exec(['install'] + flags + package)
-
-
-def snap_remove(package):
+    return _snap_exec(['install'] + flags + packages)
+
+
+def snap_remove(packages, *flags):
     """
     Remove a snap package.
 
-    :param package: String or List String package name
-    :return: None
-    """
-    if type(package) is not list:
-        package = [package]
-
-    log('Removing snap "%s"' % package)
-    _snap_exec(['remove'] + package)
+    :param packages: String or List String package name
+    :param flags: List String flags to pass to remove command
+    :return: Integer return code from snap
+    """
+    if type(packages) is not list:
+        packages = [packages]
+
+    flags = list(flags)
+
+    message = 'Removing snap(s) "%s"' % ', '.join(packages)
+    if flags:
+        message += ' with options "%s"' % ', '.join(flags)
+
+    log(message)
+    return _snap_exec(['remove'] + flags + packages)
+
+
+def snap_refresh(packages, *flags):
+    """
+    Refresh / Update snap package.
+
+    :param packages: String or List String package name
+    :param flags: List String flags to pass to refresh command
+    :return: Integer return code from snap
+    """
+    if type(packages) is not list:
+        packages = [packages]
+
+    flags = list(flags)
+
+    message = 'Refreshing snap(s) "%s"' % ', '.join(packages)
+    if flags:
+        message += ' with options "%s"' % ', '.join(flags)
+
+    log(message)
+    return _snap_exec(['refresh'] + flags + packages)

=== modified file 'docs/api/charmhelpers.contrib.snap.rst'
--- docs/api/charmhelpers.contrib.snap.rst	2017-02-24 14:11:56 +0000
+++ docs/api/charmhelpers.contrib.snap.rst	2017-02-28 12:00:55 +0000
@@ -5,3 +5,22 @@
     :members:
     :undoc-members:
     :show-inheritance:
+
+Examples
+--------
+
+.. code-block:: python
+
+    snap_install('hello-world', '--classic', '--stable')
+    snap_install(['hello-world', 'htop'])
+
+.. code-block:: python
+
+    snap_refresh('hello-world', '--classic', '--stable')
+    snap_refresh(['hello-world', 'htop'])
+
+.. code-block:: python
+
+    snap_remove('hello-world')
+    snap_remove(['hello-world', 'htop'])
+

=== modified file 'tests/contrib/snap/__init__.py'
--- tests/contrib/snap/__init__.py	2017-02-24 14:11:56 +0000
+++ tests/contrib/snap/__init__.py	2017-02-28 12:00:55 +0000
@@ -11,10 +11,8 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-import subprocess
-from mock import call
+from mock import patch
 from unittest import TestCase
-from charmhelpers.contrib.snap import snap_install, snap_remove
 
 __author__ = 'Joseph Borg <joseph.borg@canonical.com>'
 
@@ -23,32 +21,35 @@
     """
     Test and install and removal of a snap.
     """
-    def setUp(self):
-        """
-        Make sure the hello-world snap isn't installed.
-        :return: None
-        """
-        snap_remove('hello-world')
-
-    def testSnapInstall(self):
+    @patch('subprocess.Popen')
+    def testSnapInstall(self, popen):
         """
         Test snap install.
         :return: None
         """
-        snap_install('hello-world')
-        proc = subprocess.Popen(
-            ['/snap/bin/hello-world'],
-            stdout=subprocess.PIPE
-        )
-        proc.wait()
-
-        self.assertEqual(proc.stdout.read(), b'Hello World!\n')
-
-        proc.stdout.close()
-
-    def tearDown(self):
-        """
-        Remove test snap.
-        :return: None
-        """
-        snap_remove('hello-world')
+        from charmhelpers.contrib.snap import snap_install
+        popen.return_value.returncode = 0
+        snap_install(['hello-world', 'htop'], '--classic', '--stable')
+        popen.assert_called_with(['snap', 'install', '--classic', '--stable', 'hello-world', 'htop'])
+
+    @patch('subprocess.Popen')
+    def testSnapRefresh(self, popen):
+        """
+        Test snap refresh.
+        :return: None
+        """
+        from charmhelpers.contrib.snap import snap_refresh
+        popen.return_value.returncode = 0
+        snap_refresh(['hello-world', 'htop'], '--classic', '--stable')
+        popen.assert_called_with(['snap', 'refresh', '--classic', '--stable', 'hello-world', 'htop'])
+
+    @patch('subprocess.Popen')
+    def testSnapRemove(self, popen):
+        """
+        Test snap refresh.
+        :return: None
+        """
+        from charmhelpers.contrib.snap import snap_remove
+        popen.return_value.returncode = 0
+        snap_remove(['hello-world', 'htop'])
+        popen.assert_called_with(['snap', 'remove', 'hello-world', 'htop'])
\ No newline at end of file

